ReservationCreateRequestBuilder

Struct ReservationCreateRequestBuilder 

pub struct ReservationCreateRequestBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> ReservationCreateRequestBuilder<S>

pub fn build(self) -> ReservationCreateRequest
where S: IsComplete,

Finish building and return the requested object

pub fn idempotency_key( self, value: IdempotencyKey, ) -> ReservationCreateRequestBuilder<SetIdempotencyKey<S>>
where S::IdempotencyKey: IsUnset,

Optional (Some / Option setters). Default: IdempotencyKey::random().

Idempotency key for safe retries. Auto-generated if not provided.

pub fn maybe_idempotency_key( self, value: Option<IdempotencyKey>, ) -> ReservationCreateRequestBuilder<SetIdempotencyKey<S>>
where S::IdempotencyKey: IsUnset,

Optional (Some / Option setters). Default: IdempotencyKey::random().

Idempotency key for safe retries. Auto-generated if not provided.

pub fn subject( self, value: Subject, ) -> ReservationCreateRequestBuilder<SetSubject<S>>
where S::Subject: IsUnset,

Required.

Who is spending.

pub fn action( self, value: Action, ) -> ReservationCreateRequestBuilder<SetAction<S>>
where S::Action: IsUnset,

Required.

What is being done.

pub fn estimate( self, value: Amount, ) -> ReservationCreateRequestBuilder<SetEstimate<S>>
where S::Estimate: IsUnset,

Required.

Estimated cost to reserve.

pub fn ttl_ms(self, value: u64) -> ReservationCreateRequestBuilder<SetTtlMs<S>>
where S::TtlMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Time-to-live in milliseconds (default: 60000).

pub fn maybe_ttl_ms( self, value: Option<u64>, ) -> ReservationCreateRequestBuilder<SetTtlMs<S>>
where S::TtlMs: IsUnset,

Optional (Some / Option setters). Default: 60_000.

Time-to-live in milliseconds (default: 60000).

pub fn grace_period_ms( self, value: u64, ) -> ReservationCreateRequestBuilder<SetGracePeriodMs<S>>
where S::GracePeriodMs: IsUnset,

Optional (Some / Option setters). Grace period in milliseconds after TTL before expiry.

pub fn maybe_grace_period_ms( self, value: Option<u64>, ) -> ReservationCreateRequestBuilder<SetGracePeriodMs<S>>
where S::GracePeriodMs: IsUnset,

Optional (Some / Option setters). Grace period in milliseconds after TTL before expiry.

pub fn overage_policy( self, value: CommitOveragePolicy, ) -> ReservationCreateRequestBuilder<SetOveragePolicy<S>>
where S::OveragePolicy: IsUnset,

Optional (Some / Option setters). Policy when actual exceeds estimate.

pub fn maybe_overage_policy( self, value: Option<CommitOveragePolicy>, ) -> ReservationCreateRequestBuilder<SetOveragePolicy<S>>
where S::OveragePolicy: IsUnset,

Optional (Some / Option setters). Policy when actual exceeds estimate.

pub fn dry_run( self, value: bool, ) -> ReservationCreateRequestBuilder<SetDryRun<S>>
where S::DryRun: IsUnset,

Optional (Some / Option setters). Default: false.

If true, evaluate the decision without creating a reservation.

pub fn maybe_dry_run( self, value: Option<bool>, ) -> ReservationCreateRequestBuilder<SetDryRun<S>>
where S::DryRun: IsUnset,

Optional (Some / Option setters). Default: false.

If true, evaluate the decision without creating a reservation.

pub fn metadata( self, value: Value, ) -> ReservationCreateRequestBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). Arbitrary metadata to attach.

pub fn maybe_metadata( self, value: Option<Value>, ) -> ReservationCreateRequestBuilder<SetMetadata<S>>
where S::Metadata: IsUnset,

Optional (Some / Option setters). Arbitrary metadata to attach.